SetBy

Struct SetBy 

pub struct SetBy<K, F>
where F: Fn(&K, &K) -> Ordering,
{ /* private fields */ }
A simple set of keys, implemented using a splay tree.

This version allows a custom sorting function to be used.

Implementations

Source

impl<K, F> SetBy<K, F>
where F: Fn(&K, &K) -> Ordering,

pub fn new(compare: F) -> SetBy<K, F>

Constructor

pub fn with_capacity(capacity: usize, compare: F) -> SetBy<K, F>

Constructor

pub fn count(&self) -> usize

Get the number of key/value pairs in the Set

pub fn is_empty(&self) -> bool

Check if there are any key/value pairs in the Set

pub fn clear(&mut self)

Remove all key/value pairs from the Set

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more key/value pairs

pub fn get(&self, key: &K) -> Option<&K>

Get a value by key.

If the key is not in the tree then None is returned.

pub fn set(&mut self, key: K) -> &K

Set a value by key.

set attempts to reconfigure the tree for future lookups by promoting the key to the top of the tree.

pub fn unset(&mut self, key: &K) -> Option<&K>

Unset a value by key.

If the key does not exist, then this function has no effect.

pub fn first(&self) -> Option<&K>

Get the first key in the set

pub fn last(&self) -> Option<&K>

Get the last key in the set

pub fn pop_first(&self) -> Option<&K>

Pop the first key from the set

pub fn pop_last(&self) -> Option<&K>

Pop the last key from the set

pub fn iter(&self) -> SetByIterator<'_, K, F>

Iterate over the key/value pairs in the Set