Struct StringSet

pub struct StringSet { /* private fields */ }
A simple set of strings, implemented using a splay tree.

This is specialised version of Set that stores keys as a string.

Implementations

Source

impl StringSet

pub fn new() -> StringSet

Constructor

pub fn with_capacity(capacity: usize) -> StringSet

Constructor

pub fn count(&self) -> usize

Get the number of string/value pairs in the StringSet

pub fn is_empty(&self) -> bool

Check if there are any string/value pairs in the StringSet

pub fn clear(&mut self)

Remove all string/value pairs from the StringSet

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more string/value pairs

pub fn get(&self, key: &str) -> Option<&str>

Get a value by string.

If the string is not in the tree then None is returned.

pub fn set(&mut self, key: &str)

Set a value by string.

set attempts to reconfigure the tree for future lookups by promoting the string to the top of the tree.

pub fn unset(&mut self, key: &str)

Unset a value by string.

If the string does not exist, then this function has no effect.

pub fn first(&self) -> Option<&str>

Get the first string in the set

pub fn last(&self) -> Option<&str>

Get the last string in the set

pub fn pop_first(&self) -> Option<&str>

Pop the first string from the set

pub fn pop_last(&self) -> Option<&str>

Pop the last key from the set

pub fn iter(&self) -> StringSetIterator<'_>

Iterate over the string/value pairs in the StringSet